<script setup>
import { getCurrentInstance, ref, computed, reactive, nextTick } from 'vue';
import { useRouter } from "vue-router";
import { get, post, postBlob } from '@/utils/request.js'
import { message, Modal } from 'ant-design-vue';
import { logout } from '@/config.js';
import EditView from './edit.vue'
import { formatMessage } from '@/utils/localeUtils.js';
import ZpalletBarcodePrint from '@/components/print/zpalletBarcodePrint/index.vue';
import useTableSearch from '@/utils/tableUtils.jsx';
const context = getCurrentInstance()?.appContext.config.globalProperties;

const router = useRouter();

const TABLE_KEY = 'table-zpalletBarcode';
let currentPage = 1;
let pageSize = 10;
const searchInput = ref("")
const editChild = ref(null);
const printChild = ref(null);

let openGenerate = ref(false);
let generateBarcodeValue = ref("80000001");
let generateNum = ref(100);

const state = reactive({
  selectedRowKeys: [],
  loading: false,
});

let tableData = ref([]);
getPage();

const {
  getColumnSearchProps,
  handleResizeColumn,
} = useTableSearch();

const columns = [
  {
    title: formatMessage('db.man_zpallet_barcode.barcode', '容器条码'),
    dataIndex: 'barcode',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('barcode'),
  },
  {
    title: formatMessage('db.man_zpallet_barcode.flag', '标识'),
    dataIndex: 'flag',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('flag'),
  },
  {
    title: formatMessage('db.man_zpallet_barcode.barcode_print', '打印状态'),
    dataIndex: 'barcodePrint$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('barcodePrint$'),
  },
  // {
  //   title: formatMessage('db.man_zpallet_barcode.uuid', '编号'),
  //   dataIndex: 'uuid',
  //   width: 140,
  //   ellipsis: true,
  // },
  {
    title: formatMessage('db.man_zpallet_barcode.status', '状态'),
    dataIndex: 'status$',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('status$'),
  },
  // {
  //   title: formatMessage('db.man_zpallet_barcode.create_time', '添加时间'),
  //   dataIndex: 'createTime$',
  //   width: 140,
  //   ellipsis: true,
  // },
  // {
  //   title: formatMessage('db.man_zpallet_barcode.create_by', '添加人员'),
  //   dataIndex: 'createBy$',
  //   width: 140,
  //   ellipsis: true,
  // },
  // {
  //   title: formatMessage('db.man_zpallet_barcode.update_time', '修改时间'),
  //   dataIndex: 'updateTime$',
  //   width: 140,
  //   ellipsis: true,
  // },
  // {
  //   title: formatMessage('db.man_zpallet_barcode.update_by', '修改人员'),
  //   dataIndex: 'updateBy$',
  //   width: 140,
  //   ellipsis: true,
  // },
  {
    title: formatMessage('db.man_zpallet_barcode.memo', '备注'),
    dataIndex: 'memo',
    width: 140,
    ellipsis: true,
    ...getColumnSearchProps('memo'),
  },

  {
    title: formatMessage('common.operation', '操作'),
    name: 'oper',
    dataIndex: 'oper',
    key: 'oper',
    width: 140,
  },
];


const hasSelected = computed(() => state.selectedRowKeys.length > 0);
const start = () => {
  state.loading = true;
  // ajax request after empty completing
  setTimeout(() => {
    state.loading = false;
    state.selectedRowKeys = [];
  }, 1000);
};
const onSelectChange = selectedRowKeys => {
  // console.log('selectedRowKeys changed: ', selectedRowKeys);
  state.selectedRowKeys = selectedRowKeys;
};

function getPage() {
  state.loading = true;
  post('/api/zpalletBarcode/page', {
    current: currentPage,
    pageSize: pageSize,
    condition: searchInput.value
  }).then((resp) => {
    let result = resp.data;
    if (result.code == 200) {
      let data = result.data;
      tableData.value = data;

      state.loading = false;
    } else if (result.code === 401) {
      message.error(result.msg);
      logout()
    } else {
      message.error(result.msg);
    }
  })
}

const handleEdit = (item) => {
  editChild.value.open = true;
  editChild.value.formData = item == null ? editChild.value.initFormData : JSON.parse(JSON.stringify(item));
  editChild.value.isSave = item == null;
}

const handleDel = (rows) => {
  Modal.confirm({
    title: formatMessage('page.delete', '删除'),
    content: formatMessage('page.delete.confirm', '确定删除该项吗？'),
    maskClosable: true,
    onOk: async () => {
      const hide = message.loading(formatMessage('common.loading', '请求中'));
      try {
        post('/api/zpalletBarcode/remove/' + rows.map((row) => row.id).join(','), {}).then(resp => {
          let result = resp.data;
          if (result.code === 200) {
            message.success(result.msg);
          } else {
            message.error(result.msg);
          }
          getPage()
          hide()
        })
      } catch (error) {
        message.error(formatMessage('common.fail', '请求失败'));
      }
    },
  });
}

const handleExport = async (intl) => {
  postBlob('/api/zpalletBarcode/export', {}).then(result => {
    const blob = new Blob([result.data], { type: 'application/vnd.ms-excel' });
    window.location.href = window.URL.createObjectURL(blob);
    return true;
  })
};

const onSearch = () => {
  // console.log('search');
  getPage()
}

const onPageChange = (page, size) => {
  currentPage = page;
  pageSize = size;
  getPage();
}

function handleTableReload(value) {
  getPage()
}

const handleOpenGenerate = () => {
  openGenerate.value = true;
}

const handleGenerateSubmit = () => {
  post('/api/zpalletBarcode/generate', {
    barcode: generateBarcodeValue.value,
    num: generateNum.value,
  }).then((resp) => {
    let result = resp.data;
    if (result.code == 200) {
      let data = result.data;
      message.success(result.msg);
      getPage()
    } else if (result.code === 401) {
      message.error(result.msg);
      logout()
    } else {
      message.error(result.msg);
    }
  })
}

const handlePrint = () => {
    if (state.selectedRowKeys.length == 0) {
        message.warning(formatMessage('common.select', '请选择'));
        return;
    }
    let data = tableData.value.records;
    let tmp = [];
    data.forEach((item) => {
        if (state.selectedRowKeys.indexOf(item.id) != -1) {
            tmp.push(item);
        }
    })

    printChild.value.printData = tmp;
    printChild.value.open = true;
}

</script>

<script>
export default {
  name: '容器管理'
}
</script>

<template>
  <div>
    <EditView ref="editChild" @tableReload="handleTableReload" />
    <div class="table-header">
      <div>
        <a-input-search v-model:value="searchInput" :placeholder="formatMessage('page.input', '请输入')"
          style="width: 200px;" @search="onSearch" />
        <a-button @click="handlePrint()" type="primary">
          {{ formatMessage('db.man_zpallet_barcode.batchPrint', '批量打印') }}
        </a-button>
      </div>
      <div class="table-header-right">
        <a-button @click="handleOpenGenerate()" type="primary">{{
          formatMessage('db.man_zpallet_barcode.generateBarcode', '生成条码') }}</a-button>
        <a-button @click="handleEdit(null)" type="primary">{{ formatMessage('page.add', '添加') }}</a-button>
        <a-button @click="handleExport">{{ formatMessage('page.export', '导出') }}</a-button>
      </div>
    </div>
    <a-table :row-selection="{ selectedRowKeys: state.selectedRowKeys, onChange: onSelectChange }"
      :data-source="tableData.records" :defaultExpandAllRows="false" :key="TABLE_KEY" rowKey="id"
      :pagination="{ total: tableData.total, onChange: onPageChange }"
      :scroll="{ y: 768, scrollToFirstRowOnChange: true }" :columns="columns" @resizeColumn="handleResizeColumn" :loading="state.loading">
      <template #bodyCell="{ column, text, record }">
        <template v-if="column.dataIndex === 'oper'">
          <div style="display: flex;justify-content: space-evenly;">
            <a-button type="link" primary @click="handleEdit(record)">{{ formatMessage('page.edit', '编辑') }}</a-button>
            <a-button type="link" danger @click="handleDel([record])">{{ formatMessage('page.delete', '删除')
              }}</a-button>
          </div>
        </template>
      </template>
    </a-table>

    <a-modal v-model:open="openGenerate" :title="formatMessage('db.man_zpallet_barcode.generateBarcode', '生成条码')"
      @ok="handleGenerateSubmit">
      <a-form style="display: flex;justify-content: center;flex-wrap: wrap;" autocomplete="off">
        <a-form-item :label="formatMessage('db.man_zpallet_barcode.barcodeValue', '条码值')">
          <a-input v-model:value="generateBarcodeValue" />
        </a-form-item>
        <a-form-item :label="formatMessage('db.man_zpallet_barcode.generateNum', '生成数量')">
          <a-input v-model:value="generateNum" />
        </a-form-item>
      </a-form>
    </a-modal>

    <ZpalletBarcodePrint ref="printChild" />
  </div>
</template>

<style></style>
